*********************
:mod:`mopidy.outputs`
*********************

Outputs are responsible for playing audio.


Output API
==========

A stable output API is not available yet, as we've only implemented a single
output module.


:mod:`mopidy.outputs.gstreamer` -- GStreamer output for all platforms
=====================================================================

.. inheritance-diagram:: mopidy.outputs.gstreamer

.. automodule:: mopidy.outputs.gstreamer
    :synopsis: GStreamer output for all platforms
    :members:
